Crate u_os_hub_client

Crate u_os_hub_client 

Welcome to the u-OS Data Hub client library.

This library allows to interact with the u-OS Variable Data Hub as a provider or consumer.

As a starting point, please take a look at the provider and consumer module documentation. They provide example code and a detailed description of the available APIs.

Features

  • export-low-level-api - Exports low level features as public API. See consumer module documentation for details about the low level api. (Default: false)

Modules

authenticated_nats_con
Handles authentication and connection to NATS server. Used by both provider and consumer modules.
consumer
This module provides APIs and data types for interacting with the u-OS Data Hub as a consumer.
dh_types
Collection of types that are used in the library. These types abstract the low level flatbuffer types and provide a more user-friendly interface.
env_file_parser
Parser for environment files.
nats_subjects
Contains constants and functions for dealing with the u-OS Data Hub subjects
oauth2
Provides utilities for OAuth2 handling
payload_builders
Contains flatbuffers payload builders.
provider
This module provides APIs and data types for interacting with the u-OS Data Hub as a provider. Providers are responsible for providing variables to the Data Hub and managing their values. They can publish data and accept write requests from consumers. All providers are managed by the Data Hub registry.
variable
Contains a variable with definition and value
variable_definition_serde_extension
variable_value_type_serde_extension